lasertag.cached


add-tags!*clj/s

(add-tags!* x vol f & tags)
source

all-tags*clj/s

(all-tags* x)
(all-tags* x {:keys [runtime?]})

All tags, for values at macroexpansion.

All tags, for values at macroexpansion.
sourceraw docstring

array-map?clj/s

(array-map? x)
source

big-decimal?clj/s

(big-decimal? x)
source

big-int?clj/s

(big-int? x)
source

by-classclj/s

source

by-class*cljmacro

(by-class* m)

Supplied with a map of example values, generates a map of cached results for calls to lasertag.core/tag-map.

Example entry input: [[clojure.lang.PersistentHashMap :map] (hash-map :a 1)]

Example entry output: [clojure.lang.PersistentHashMap {:tag :map, :type clojure.lang.PersistentHashMap, :all-tags #{:callable :seqable :editable :associative :coll :array-map :coll-like :hash-map :map-like :map :carries-meta}, :classname "clojure.lang.PersistentHashMap"}]

Supplied with a map of example values, generates a map of cached results
for calls to lasertag.core/tag-map.

Example entry input:
  [[clojure.lang.PersistentHashMap :map] (hash-map :a 1)]

Example entry output:
  [clojure.lang.PersistentHashMap 
    {:tag :map,
     :type clojure.lang.PersistentHashMap,
     :all-tags
     #{:callable
       :seqable
       :editable
       :associative
       :coll
       :array-map
       :coll-like
       :hash-map
       :map-like
       :map
       :carries-meta},
     :classname "clojure.lang.PersistentHashMap"}]
sourceraw docstring

by-number-classclj/s

source

byte?clj/s

(byte? x)
source

callable?clj/s

(callable? v)
source

carries-meta?clj/s

(carries-meta? x)
source

char-sequence?clj/s

(char-sequence? x)
source

chunked-cons?clj/s≠

(chunked-cons? x)
clj

Returns true if x implements clojure.lang.ChunkedCons

Returns true if x implements `clojure.lang.ChunkedCons`
cljs

Returns true if x implements cljs.core/ChunkedCons

Returns true if x implements `cljs.core/ChunkedCons`
sourceraw docstring

cljc-array?clj/s

(cljc-array? x)
source

cljc-coll-typeclj/s

(cljc-coll-type x)

Provides a primary tag for:

  • Data structures whose class constructor may not be present in cached map, such as various data structures that implement ISeq.
  • Custom cljc data structures that are implemented on top of standard cljc collection interfaces.
Provides a primary tag for:
- Data structures whose class constructor may not be present in cached map,
  such as various data structures that implement ISeq. 
- Custom cljc data structures that are implemented on top of standard cljc
  collection interfaces.
sourceraw docstring

cljc-map-entry?clj/s

(cljc-map-entry? x)
source

cljc-ratio?clj/s

(cljc-ratio? x)
source

cljc-transients-primary-tags-by-classclj/s

source

cljc-typeclj/s

(cljc-type x)

Cljc-friendly and safe alternative to clojure.core/type.

clojure.core/type would return :foo in this example case: (type (with-meta [1] {:type :foo}))

cljc-type will always return the class (or constructor in cljs).

Cljc-friendly and safe alternative to `clojure.core/type`.

`clojure.core/type` would return `:foo` in this example case:
`(type (with-meta [1] {:type :foo}))`

`cljc-type` will always return the class (or constructor in cljs).
sourceraw docstring

coll-like?clj/s

(coll-like? v)
source

comment-box-textclj

This is used to generate the header of a test file saved in gen-test-path

This is used to generate the header of a test file saved in `gen-test-path`
sourceraw docstring

cons?clj/s≠

(cons? x)
clj

Returns true if x implements clojure.lang.Cons

Returns true if x implements `clojure.lang.Cons`
cljs

Returns true if x implements cljs.core/Cons

Returns true if x implements `cljs.core/Cons`
sourceraw docstring

data-type?clj/s

(data-type? x)
source

deferred?clj/s

(deferred? x)
source

derefable?clj/s

(derefable? x)
source

different-behaviorcljmultimethod

source

editable?clj/s

(editable? x)
source

error?clj/s

(error? x)
source

exception?clj/s

(exception? x)
source

fractional-number?clj/s

(fractional-number? n)
source

gen-test-ns-nameclj/s

source

gen-test-pathclj/s

source

hash-map?clj/s

(hash-map? x)
source

hash-set?clj/s

(hash-set? x)
source

integer-range?clj/s≠

(integer-range? x)
clj

Returns true if x implements clojure.lang.LongRange

Returns true if x implements `clojure.lang.LongRange`
cljs

Returns true if x implements cljs.core/IntegerRange

Returns true if x implements `cljs.core/IntegerRange`
sourceraw docstring

iterate?clj/s≠

(iterate? x)
clj

Returns true if x implements clojure.lang.Iterate

Returns true if x implements `clojure.lang.Iterate`
cljs

Returns true if x implements cljs.core/Iterate

Returns true if x implements `cljs.core/Iterate`
sourceraw docstring

java-class?clj/s

(java-class? s)
source

java-lang-class?clj/s

(java-lang-class? s)
source

java-util-class?clj/s

(java-util-class? s)
source

js-array-buffer?clj/s

(js-array-buffer? x)
source

js-array?clj/s

(js-array? x)
source

js-data-view?clj/s

(js-data-view? x)
source

js-global-this?clj/s

(js-global-this? x)
source

js-intl?clj/s

(js-intl? x)
source

js-map?clj/s

(js-map? v)
source

js-object-instance?clj/s

(js-object-instance? x)
source

js-object?clj/s

(js-object? x)
source

js-promise?clj/s

(js-promise? x)
source

js-set?clj/s

(js-set? v)
source

lazy-seq?clj/s≠

(lazy-seq? x)
clj

Returns true if x implements clojure.lang.LazySeq

Returns true if x implements `clojure.lang.LazySeq`
cljs

Returns true if x implements cljs.core/LazySeq

Returns true if x implements `cljs.core/LazySeq`
sourceraw docstring

lazyish-seq?clj/s

(lazyish-seq? x)
source

list-like?clj/s

(list-like? v)
source

long?clj/s

(long? x)
source

map-like?clj/s

(map-like? v)
source

multi-function?clj/s

(multi-function? x)
source

my-varclj

source

named?clj/s

(named? x)
source

NaNclj/s

source

non-finite-numbers-by-classclj/s

source

number-tagsclj/s

(number-tags x)

All secondary number tags, for values at runtime.

All secondary number tags, for values at runtime.
sourceraw docstring

queue?clj/s

(queue? v)
source

range?clj/s≠

(range? x)
clj

Returns true if x implements clojure.lang.Range

Returns true if x implements `clojure.lang.Range`
cljs

Returns true if x implements cljs.core/Range

Returns true if x implements `cljs.core/Range`
sourceraw docstring

real-number?clj/s

(real-number? n)
source

reference?clj/s

(reference? x)

Returns true if x is a reference type.

Returns true if x is a reference type.
sourceraw docstring

repeat?clj/s≠

(repeat? x)
clj

Returns true if x implements clojure.lang.Repeat

Returns true if x implements `clojure.lang.Repeat`
cljs

Returns true if x implements cljs.core/Repeat

Returns true if x implements `cljs.core/Repeat`
sourceraw docstring

scalar?clj/s

(scalar? x)
source

set-like?clj/s

(set-like? v)
source

short?clj/s

(short? x)
source

spit-test-headerclj

(spit-test-header)
source

stack?clj/s

(stack? x)
source

subvec-classclj/s

source

subvec?clj/s

(subvec? x)
source

temporal?clj/s

(temporal? x)
source

throwable?clj/s

(throwable? x)
source

transient-array-map-classclj/s

source

transient-hash-map-classclj/s

source

transient-hash-set-classclj/s

source

transient-vector-classclj/s

source

transient?clj/s

(transient? v)
source

whole-number?clj/s

(whole-number? n)
source

cljdoc builds & hosts documentation for Clojure/Script libraries