lasertag.jsi.codegen


Atomicscljs

source

autogen-file-header-commentcljs

(autogen-file-header-comment & lines)

This is used as the comment header of the generated file

This is used as the comment header of the generated file
sourceraw docstring

by-classcljs

source

by-class*cljs

source

different-behaviorcljsmultimethod

source

header-commentcljs

source

header-comment+namespace-formcljs

(header-comment+namespace-form s form)
source

maincljs

(main)
source

test-pathcljs

source

with-datafied-demosclj/smacro

(with-datafied-demos m)
source

write-classes!cljs

(write-classes!)
source

write-file-sync!cljs

(write-file-sync! filepath content)
(write-file-sync! filepath content opts)

Write content to filepath, creating or overwriting it.

Write `content` to `filepath`, creating or overwriting it.
sourceraw docstring

write-tests!cljs

(write-tests!)
source

cljdoc builds & hosts documentation for Clojure/Script libraries