lasertag.jsi.tag


dom-node-type-keywordscljs

source

dom-node-typescljs

source

js-map-typescljs

source

js-set-typescljs

source

k*cljs

(k* x t)

Assigns a primary tag for values that cannot be found in any of the public lasertag.cached/* maps.

Assigns a primary tag for values that cannot be found in any of the public
lasertag.cached/* maps.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries