All platforms.

lasertag.macros


!?clj/smacro

(!?)
(!? x)
(!? _ x)
source

!?>clj/smacro

(!?> x)
source

?clj/smacro

(?)
(? x)
(? label x)

Prints the value and returns the value.

Prints the value and returns the value.
sourceraw docstring

?>clj/smacro

(?> x)

Passes value to clojure.core/tap> and returns value.

Passes value to clojure.core/tap> and returns value.
sourceraw docstring

ppclj/s

source

shortenedclj/s

(shortened v limit)

Stringifies a collection and truncates the result with ellipsis so that it fits on one line.

Stringifies a collection and truncates the result with ellipsis 
so that it fits on one line.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries