All platforms.

lasertag.messaging


as-strclj/s

(as-str x)
source

shortenedclj/s

(shortened v limit)

Stringifies a value and truncates the result with ellipsis so that it fits on one line.

Stringifies a value and truncates the result with ellipsis 
so that it fits on one line.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries