(all-tags* x)(all-tags* x {:keys [runtime?]})All tags, for values at macroexpansion.
All tags, for values at macroexpansion.
(by-class* m)Supplied with a map of example values, generates a map of cached results for calls to lasertag.core/tag-map.
Example entry input: [[clojure.lang.PersistentHashMap :map] (hash-map :a 1)]
Example entry output: [clojure.lang.PersistentHashMap {:tag :map, :type clojure.lang.PersistentHashMap, :all-tags #{:callable :seqable :editable :associative :coll :array-map :coll-like :hash-map :map-like :map :carries-meta}, :classname "clojure.lang.PersistentHashMap"}]
Supplied with a map of example values, generates a map of cached results
for calls to lasertag.core/tag-map.
Example entry input:
[[clojure.lang.PersistentHashMap :map] (hash-map :a 1)]
Example entry output:
[clojure.lang.PersistentHashMap
{:tag :map,
:type clojure.lang.PersistentHashMap,
:all-tags
#{:callable
:seqable
:editable
:associative
:coll
:array-map
:coll-like
:hash-map
:map-like
:map
:carries-meta},
:classname "clojure.lang.PersistentHashMap"}]
(chunked-cons? x)Returns true if x implements clojure.lang.ChunkedCons
Returns true if x implements `clojure.lang.ChunkedCons`
Returns true if x implements cljs.core/ChunkedCons
Returns true if x implements `cljs.core/ChunkedCons`
(cljc-coll-type x)Provides a primary tag for:
Provides a primary tag for: - Data structures whose class constructor may not be present in cached map, such as various data structures that implement ISeq. - Custom cljc data structures that are implemented on top of standard cljc collection interfaces.
(cljc-type x)Cljc-friendly and safe alternative to clojure.core/type.
clojure.core/type would return :foo in this example case:
(type (with-meta [1] {:type :foo}))
cljc-type will always return the class (or constructor in cljs).
Cljc-friendly and safe alternative to `clojure.core/type`.
`clojure.core/type` would return `:foo` in this example case:
`(type (with-meta [1] {:type :foo}))`
`cljc-type` will always return the class (or constructor in cljs).This is used to generate the header of a test file saved in gen-test-path
This is used to generate the header of a test file saved in `gen-test-path`
(cons? x)Returns true if x implements clojure.lang.Cons
Returns true if x implements `clojure.lang.Cons`
Returns true if x implements cljs.core/Cons
Returns true if x implements `cljs.core/Cons`
(integer-range? x)Returns true if x implements clojure.lang.LongRange
Returns true if x implements `clojure.lang.LongRange`
Returns true if x implements cljs.core/IntegerRange
Returns true if x implements `cljs.core/IntegerRange`
(iterate? x)Returns true if x implements clojure.lang.Iterate
Returns true if x implements `clojure.lang.Iterate`
Returns true if x implements cljs.core/Iterate
Returns true if x implements `cljs.core/Iterate`
(lazy-seq? x)Returns true if x implements clojure.lang.LazySeq
Returns true if x implements `clojure.lang.LazySeq`
Returns true if x implements cljs.core/LazySeq
Returns true if x implements `cljs.core/LazySeq`
(number-tags x)All secondary number tags, for values at runtime.
All secondary number tags, for values at runtime.
(range? x)Returns true if x implements clojure.lang.Range
Returns true if x implements `clojure.lang.Range`
Returns true if x implements cljs.core/Range
Returns true if x implements `cljs.core/Range`
(reference? x)Returns true if x is a reference type.
Returns true if x is a reference type.
(repeat? x)Returns true if x implements clojure.lang.Repeat
Returns true if x implements `clojure.lang.Repeat`
Returns true if x implements cljs.core/Repeat
Returns true if x implements `cljs.core/Repeat`
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |