(k* x t)Assigns a primary tag for values that cannot be found in any of the public lasertag.cached/* maps.
Assigns a primary tag for values that cannot be found in any of the public lasertag.cached/* maps.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |