(?)(? x)(? label x)Prints the value and returns the value.
Prints the value and returns the value.
(?> x)Passes value to clojure.core/tap> and returns value.
Passes value to clojure.core/tap> and returns value.
(shortened v limit)Stringifies a collection and truncates the result with ellipsis so that it fits on one line.
Stringifies a collection and truncates the result with ellipsis so that it fits on one line.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |