(shortened v limit)Stringifies a value and truncates the result with ellipsis so that it fits on one line.
Stringifies a value and truncates the result with ellipsis so that it fits on one line.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |